# IndicatorManagement

A library to help management of fully customized indicators.

# Features

This library provides management of financial indicators, without having any problem on large amount of series data.

# Dependencies

- Python 3.10+

# Installation

```
pip install indicator-management
```

# Examples

Please have a look at `examples` folder.

# Planned Future Features

- Implement financial indicators including MACD, RSI, Bollinger Bands, etc
